<?php

namespace Drupal\user_online_status\Plugin\views\field;

use Drupal\user\Entity\User;
use Drupal\user_online_status\StatusService;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ResultRow;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Field handler to flag the node type.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("user_online_status")
 */
class UserOnlineStatus extends FieldPluginBase {

  /**
   * The user's online status service.
   *
   * @var Drupal\user_online_status\StatusService
   */
  protected $userOnlineStatusService;

  /**
   * Constructs a User online status field plugin.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param Drupal\user_online_status\StatusService $status_service
   *   The user online status service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, StatusService $status_service) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->userOnlineStatusService = $status_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('user_online_status.status_service')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function query() {
    // Leave empty to avoid a query on this field.
  }

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    if ($values->_entity instanceof User) {
      return $this->userOnlineStatusService->getUserStatus($values->_entity);
    }
  }

}
